@@ -8,12 +8,15 @@ class WH:
     of the water heater tank with electric resistance heating (efficiency ~=100%)
     """
     def __init__(self, hems):
+        # set the centralized hems for current sensor values
         self.hems = hems
+
+        # optimization variables
         self.temp_wh_ev = cp.Variable(self.hems.h_plus)
         self.temp_wh = cp.Variable(1)
         self.temp_wh0 = cp.Variable(1)
-        self.wh_heat_max = self.hems.sub_subhourly_steps
-        self.wh_heat_min = 0
+        self.heat_on = cp.Variable(self.hems.horizon, integer=True)
+        self.p_elec = cp.Variable(self.hems.horizon)
 
         # Water heater temperature constants
         self.r = cp.Constant(float(self.hems.home["wh"]["r"]) * 1000)
@@ -21,14 +24,14 @@ class WH:
         self.temp_wh_min = cp.Constant(float(self.hems.home["wh"]["temp_wh_min"]))
         self.temp_wh_max = cp.Constant(float(self.hems.home["wh"]["temp_wh_max"]))
         self.temp_wh_sp = cp.Constant(float(self.hems.home["wh"]["temp_wh_sp"]))
-        self.wh_size = float(self.hems.home["wh"]["tank_size"])
+        self.wh_size = float(self.hems.home["wh"]["tank_size"]) # in liters
         self.tap_temp = 15 # assumed cold tap water is about 55 deg F
         wh_capacitance = self.wh_size * 4.2 # kJ/deg C
         self.c = cp.Constant(wh_capacitance)
-
-        self.heat_on = cp.Variable(self.hems.horizon, integer=True)
-        self.p_elec = cp.Variable(self.hems.horizon)
-
+        self.wh_heat_max = self.hems.sub_subhourly_steps # integer represents duty cycle
+        self.wh_heat_min = 0
+        
+        # initilize water draws
         self._get_water_draws()
         self.opt_keys = {"waterdraws", "temp_wh_opt", "wh_heat_on_opt"}
 
@@ -61,27 +64,32 @@ class WH:
         A method to introduce physical constraints to the water heater. 
         """
         self._get_water_draws()
+
         cons = [
-            # Hot water heater contraints, expected value after approx waterdraws
+            # thermal constraints, expected value after approx waterdraws
             self.temp_wh_ev[0] == self.hems.temp_wh_init,
             self.temp_wh_ev[1:] == (cp.multiply(self.remainder_frac[1:],self.temp_wh_ev[:-1]) 
                                 + self.draw_frac[1:]*self.tap_temp)
-                                + 3600 * ((((self.hems.hvac.temp_in_ev[1:] 
+                                + (3600 * self.hems.dt_frac) * ((((self.hems.hvac.temp_in_ev[1:] 
                                     - (cp.multiply(self.remainder_frac[1:],self.temp_wh_ev[:-1]) 
                                     + self.draw_frac[1:]*self.tap_temp)) / self.r))
-                                    + self.heat_on * self.p) / (self.c * self.hems.dt),
+                                    + self.heat_on * self.p) / (self.c),
 
+            # actual value of temperature of tank at time t="-0.5", before any water draw occurs
             self.temp_wh0 == self.hems.temp_wh_init
-                            + 3600 * (((self.hems.hvac.temp_in - self.hems.temp_wh_init) / self.r)
-                            + self.heat_on[0] * self.p) / (self.c * self.hems.dt),
+                            + (3600 * self.hems.dt_frac) * (((self.hems.hvac.temp_in - self.hems.temp_wh_init) / self.r)
+                            + self.heat_on[0] * self.p) / (self.c),
 
+            # actual value of temperature of tank at time t=0, after any water draw occurs, before heating
             self.temp_wh == ((self.temp_wh0 * (self.wh_size - self.draw_size[0])) + (self.tap_temp * self.draw_size[0])) / self.wh_size,
 
+            # electrical power as a function of thermal power
             self.heat_on <= self.wh_heat_max,
             self.heat_on >= self.wh_heat_min,
             self.p_elec == self.heat_on * self.p]
 
         if enforce_bounds:
+            # optional comfort constraints
             cons += [
                     self.temp_wh >= self.temp_wh_min,
                     self.temp_wh <= self.temp_wh_max,
